@@ -8,6 +8,7 @@
 #include <aws/core/utils/memory/stl/AWSString.h>
 #include <aws/s3-crt/model/ArchiveStatus.h>
 #include <aws/core/utils/DateTime.h>
+#include <aws/s3-crt/model/ChecksumType.h>
 #include <aws/s3-crt/model/ServerSideEncryption.h>
 #include <aws/core/utils/memory/stl/AWSMap.h>
 #include <aws/s3-crt/model/StorageClass.h>
@@ -147,12 +148,12 @@ namespace Model
 
     ///@{
     /**
-     * <p>The base64-encoded, 32-bit CRC-32 checksum of the object. This will only be
-     * present if it was uploaded with the object. When you use an API operation on an
-     * object that was uploaded using multipart uploads, this value may not be a direct
-     * checksum value of the full object. Instead, it's a calculation based on the
-     * checksum values of each individual part. For more information about how
-     * checksums are calculated with multipart uploads, see <a
+     * <p>The Base64 encoded, 32-bit <code>CRC32 checksum</code> of the object. This
+     * checksum is only be present if the checksum was uploaded with the object. When
+     * you use an API operation on an object that was uploaded using multipart uploads,
+     * this value may not be a direct checksum value of the full object. Instead, it's
+     * a calculation based on the checksum values of each individual part. For more
+     * information about how checksums are calculated with multipart uploads, see <a
      * href="https://docs.aws.amazon.com/AmazonS3/latest/userguide/checking-object-integrity.html#large-object-checksums">
      * Checking object integrity</a> in the <i>Amazon S3 User Guide</i>.</p>
      */
@@ -167,12 +168,12 @@ namespace Model
 
     ///@{
     /**
-     * <p>The base64-encoded, 32-bit CRC-32C checksum of the object. This will only be
-     * present if it was uploaded with the object. When you use an API operation on an
-     * object that was uploaded using multipart uploads, this value may not be a direct
-     * checksum value of the full object. Instead, it's a calculation based on the
-     * checksum values of each individual part. For more information about how
-     * checksums are calculated with multipart uploads, see <a
+     * <p>The Base64 encoded, 32-bit <code>CRC32C</code> checksum of the object. This
+     * checksum is only present if the checksum was uploaded with the object. When you
+     * use an API operation on an object that was uploaded using multipart uploads,
+     * this value may not be a direct checksum value of the full object. Instead, it's
+     * a calculation based on the checksum values of each individual part. For more
+     * information about how checksums are calculated with multipart uploads, see <a
      * href="https://docs.aws.amazon.com/AmazonS3/latest/userguide/checking-object-integrity.html#large-object-checksums">
      * Checking object integrity</a> in the <i>Amazon S3 User Guide</i>.</p>
      */
@@ -187,12 +188,28 @@ namespace Model
 
     ///@{
     /**
-     * <p>The base64-encoded, 160-bit SHA-1 digest of the object. This will only be
-     * present if it was uploaded with the object. When you use the API operation on an
-     * object that was uploaded using multipart uploads, this value may not be a direct
-     * checksum value of the full object. Instead, it's a calculation based on the
-     * checksum values of each individual part. For more information about how
-     * checksums are calculated with multipart uploads, see <a
+     * <p>The Base64 encoded, 64-bit <code>CRC64NVME</code> checksum of the object. For
+     * more information, see <a
+     * href="https://docs.aws.amazon.com/AmazonS3/latest/userguide/checking-object-integrity.html">Checking
+     * object integrity in the Amazon S3 User Guide</a>.</p>
+     */
+    inline const Aws::String& GetChecksumCRC64NVME() const{ return m_checksumCRC64NVME; }
+    inline void SetChecksumCRC64NVME(const Aws::String& value) { m_checksumCRC64NVME = value; }
+    inline void SetChecksumCRC64NVME(Aws::String&& value) { m_checksumCRC64NVME = std::move(value); }
+    inline void SetChecksumCRC64NVME(const char* value) { m_checksumCRC64NVME.assign(value); }
+    inline HeadObjectResult& WithChecksumCRC64NVME(const Aws::String& value) { SetChecksumCRC64NVME(value); return *this;}
+    inline HeadObjectResult& WithChecksumCRC64NVME(Aws::String&& value) { SetChecksumCRC64NVME(std::move(value)); return *this;}
+    inline HeadObjectResult& WithChecksumCRC64NVME(const char* value) { SetChecksumCRC64NVME(value); return *this;}
+    ///@}
+
+    ///@{
+    /**
+     * <p>The Base64 encoded, 160-bit <code>SHA1</code> digest of the object. This will
+     * only be present if the object was uploaded with the object. When you use the API
+     * operation on an object that was uploaded using multipart uploads, this value may
+     * not be a direct checksum value of the full object. Instead, it's a calculation
+     * based on the checksum values of each individual part. For more information about
+     * how checksums are calculated with multipart uploads, see <a
      * href="https://docs.aws.amazon.com/AmazonS3/latest/userguide/checking-object-integrity.html#large-object-checksums">
      * Checking object integrity</a> in the <i>Amazon S3 User Guide</i>.</p>
      */
@@ -207,12 +224,12 @@ namespace Model
 
     ///@{
     /**
-     * <p>The base64-encoded, 256-bit SHA-256 digest of the object. This will only be
-     * present if it was uploaded with the object. When you use an API operation on an
-     * object that was uploaded using multipart uploads, this value may not be a direct
-     * checksum value of the full object. Instead, it's a calculation based on the
-     * checksum values of each individual part. For more information about how
-     * checksums are calculated with multipart uploads, see <a
+     * <p>The Base64 encoded, 256-bit <code>SHA256</code> digest of the object. This
+     * will only be present if the object was uploaded with the object. When you use an
+     * API operation on an object that was uploaded using multipart uploads, this value
+     * may not be a direct checksum value of the full object. Instead, it's a
+     * calculation based on the checksum values of each individual part. For more
+     * information about how checksums are calculated with multipart uploads, see <a
      * href="https://docs.aws.amazon.com/AmazonS3/latest/userguide/checking-object-integrity.html#large-object-checksums">
      * Checking object integrity</a> in the <i>Amazon S3 User Guide</i>.</p>
      */
@@ -225,6 +242,23 @@ namespace Model
     inline HeadObjectResult& WithChecksumSHA256(const char* value) { SetChecksumSHA256(value); return *this;}
     ///@}
 
+    ///@{
+    /**
+     * <p>The checksum type, which determines how part-level checksums are combined to
+     * create an object-level checksum for multipart objects. You can use this header
+     * response to verify that the checksum type that is received is the same checksum
+     * type that was specified in <code>CreateMultipartUpload</code> request. For more
+     * information, see <a
+     * href="https://docs.aws.amazon.com/AmazonS3/latest/userguide/checking-object-integrity.html">Checking
+     * object integrity in the Amazon S3 User Guide</a>.</p>
+     */
+    inline const ChecksumType& GetChecksumType() const{ return m_checksumType; }
+    inline void SetChecksumType(const ChecksumType& value) { m_checksumType = value; }
+    inline void SetChecksumType(ChecksumType&& value) { m_checksumType = std::move(value); }
+    inline HeadObjectResult& WithChecksumType(const ChecksumType& value) { SetChecksumType(value); return *this;}
+    inline HeadObjectResult& WithChecksumType(ChecksumType&& value) { SetChecksumType(std::move(value)); return *this;}
+    ///@}
+
     ///@{
     /**
      * <p>An entity tag (ETag) is an opaque identifier assigned by a web server to a
@@ -334,6 +368,20 @@ namespace Model
     inline HeadObjectResult& WithContentType(const char* value) { SetContentType(value); return *this;}
     ///@}
 
+    ///@{
+    /**
+     * <p>The portion of the object returned in the response for a <code>GET</code>
+     * request.</p>
+     */
+    inline const Aws::String& GetContentRange() const{ return m_contentRange; }
+    inline void SetContentRange(const Aws::String& value) { m_contentRange = value; }
+    inline void SetContentRange(Aws::String&& value) { m_contentRange = std::move(value); }
+    inline void SetContentRange(const char* value) { m_contentRange.assign(value); }
+    inline HeadObjectResult& WithContentRange(const Aws::String& value) { SetContentRange(value); return *this;}
+    inline HeadObjectResult& WithContentRange(Aws::String&& value) { SetContentRange(std::move(value)); return *this;}
+    inline HeadObjectResult& WithContentRange(const char* value) { SetContentRange(value); return *this;}
+    ///@}
+
     ///@{
     /**
      * <p>The date and time at which the object is no longer cacheable.</p>
@@ -616,10 +664,14 @@ namespace Model
 
     Aws::String m_checksumCRC32C;
 
+    Aws::String m_checksumCRC64NVME;
+
     Aws::String m_checksumSHA1;
 
     Aws::String m_checksumSHA256;
 
+    ChecksumType m_checksumType;
+
     Aws::String m_eTag;
 
     int m_missingMeta;
@@ -636,6 +688,8 @@ namespace Model
 
     Aws::String m_contentType;
 
+    Aws::String m_contentRange;
+
     Aws::Utils::DateTime m_expires;
 
     Aws::String m_websiteRedirectLocation;
